@@ -57,7 +57,7 @@ class Resource():
         return sorted(resource_paths, key=len)
 
     def get_resource_path(self, name):
-        assert '/' not in name
+        assert os.sep not in name
         for f in self.resource_paths:
             if f.endswith(name):
                 return f
