@@ -54,19 +54,18 @@ class Word():
     def get_pmt_formulas(self, _max, _oper, count=None):  # for plus/minus/time
         f = []
         count = count if count else self.count
-        if isinstance(_oper, list):
-            for _ in range(self.count + 1):
-                f.append(
-                    str(random.randint(0, _max)) + ' ' + random.choice(_oper) +
-                    ' ' + str(random.randint(0, _max)))
-        else:
-            for _ in range(self.count + 1):
-                f.append(
-                    str(random.randint(0, _max)) +
-                    ' ' +
-                    _oper +
-                    ' ' +
-                    str(random.randint(0, _max)))
+        _max_sqrt = int(_max**0.5)
+        for _ in range(self.count + 1):
+            _oper_ = random.choice(_oper) if isinstance(_oper, list) else _oper
+            num0 = random.randint(0, _max)
+            num1 = random.randint(0, _max)
+            if _oper_ == '-':
+                num0 = max(num0, num1)
+                num1 = min(num0, num1)
+            if _oper_ == '*':
+                num0 = random.randint(0, _max_sqrt)
+                num1 = random.randint(0, _max_sqrt)
+            f.append(str(num0) + ' ' + _oper_ + ' ' + str(num1))
 
         return f
 
