@@ -53,12 +53,12 @@ class Word():
     def __init__(self, pm):
         self.pm = pm
         self.win = self.pm.win
-        self.rand_word_count = 50
+        self.rand_word_count = 70
         pass
 
     def get_words(self, g: int):
         if g == 15:
-            return self.get_rand_words(250)
+            return self.get_rand_words(self.rand_word_count)
         if 0 <= g < 15:
             return self.get_cn_ps_words(g)
 
@@ -144,11 +144,45 @@ class WallSurface():
         self.win = self.pm.win
         self.h = self.pm.w_height / 20
         self.surface = pygame.Surface((self.pm.w_width, self.h))
-        self.color = (255, 200, 99)
+        self.color = self.get_default_color()
         self.emitter_radius = self.h / 2
         self.emitter_color = None
-
         self.center = self.get_center()
+        self.flicker_interval = 1 * self.win.FPS  # 2s
+        self.flicker_counter = 0
+        self.flicker_color = [self.color, (250, 0, 0)]
+        self.flicker_color_step = (
+            (self.flicker_color[1][0] - self.flicker_color[0][0])
+            / self.flicker_interval,
+            (self.flicker_color[1][1] - self.flicker_color[0][1])
+            / self.flicker_interval,
+            (self.flicker_color[1][2] - self.flicker_color[0][2])
+            / self.flicker_interval,
+        )
+
+    def get_default_color(self):
+        return (10, 200, 99)
+
+    def flicker(self):
+        self.flicker_counter += 1
+        self.color = (
+            min(
+                int(self.flicker_color[0][0]
+                    + self.flicker_color_step[0] * self.flicker_counter),
+                255),
+            min(
+                int(self.flicker_color[0][1]
+                    + self.flicker_color_step[1] * self.flicker_counter),
+                255),
+            min(
+                int(self.flicker_color[0][2]
+                    + self.flicker_color_step[2] * self.flicker_counter),
+                255)
+        )
+        if self.flicker_counter >= self.flicker_interval:
+            self.flicker_counter = 0
+            self.color = self.get_default_color()
+        return self.flicker_counter
 
     def set_emitter_color(self, color=(255, 0, 0, 50)):
         self.emitter_color = color
@@ -175,6 +209,7 @@ class WallSurface():
 class WordSurfacesManager():
     def __init__(self, pm, frame_counter=0):
         self.pm = pm
+        self.words = self.pm.words
         self.win = self.pm.win
         self.moving_surfaces = []
         self.frame_counter = frame_counter
@@ -198,8 +233,8 @@ class WordSurfacesManager():
         return self.font_size
 
     def set_surfaces(self):
-        assert len(self.pm.words) > 0
-        self.surfaces = [WordSurface(self.pm, self, w) for w in self.pm.words]
+        assert len(self.words) > 0
+        self.surfaces = [WordSurface(self.pm, self, w) for w in self.words]
 
     def get_surfaces(self):
         if not self.surfaces:
@@ -237,19 +272,18 @@ class WordSurfacesManager():
         if len(self.surfaces) > 0:
             if len(self.moving_surfaces) < 1:
                 self.add_moving_surfaces()
-
             if self.frame_counter >= self.interval:
                 self.add_moving_surfaces()
 
         for w in self.moving_surfaces:
-
             if w.intercepted:
                 if w.intercept_frame_counter >= self.intercept_interval:
                     self.moving_surfaces.remove(w)
                 self.pm.wave.draw(w.intercept_frame_counter)
                 w.surface = w.font.render(
-                    w.word, False, self.intercepted_color)
-                self.pm.surface.blit(w.surface, w.dest)
+                    w.word, False,
+                    self.intercepted_color)
+                w.blit()
                 w.circle()
                 w.draw_laser_line()
                 w.intercept_frame_counter += 1
@@ -258,17 +292,17 @@ class WordSurfacesManager():
             if w.intercept(self.pm._input):
                 self.pm._input = ''
                 self.pm.input_surface._update()
-                self.pm.surface.blit(w.surface, w.dest)
                 self.pm.win_count += 1
+                w.blit()
                 continue
 
             if w.arrived():
-                self.moving_surfaces.remove(w)
-                self.pm.lose_count += 1
-                continue
+                if self.pm.wall_surface.flicker() < 1:
+                    self.moving_surfaces.remove(w)
+                    self.pm.lose_count += 1
+                    continue
 
-            w.add_dest((0, self.moving_speed))
-            self.pm.surface.blit(w.surface, w.dest)
+            w.add_dest((0, self.moving_speed), blit=True)
 
         self.frame_counter += 1
 
@@ -416,7 +450,7 @@ class WordSurface():
         self.font_color = (200, 22, 98)
         self.font = self.manager.font
         self.circle_color = (100, 20, 25, 20)
-        self.circle_width = 4
+        self.circle_width = 6
         self.intercepted = False
         self.intercept_frame_counter = 0
         self.laser_color = self.manager.laser_color
@@ -427,6 +461,28 @@ class WordSurface():
         self.dest = dest if dest else self.get_random_dest()
         self.center = self.get_center()
         self.pinyins = self.get_pinyins()
+        self.tip_height = None
+        self.bg_color = None
+
+    def set_tip_height(self, height=50):
+        self.tip_height = height
+
+    def get_tip_height(self):
+        if not self.tip_height:
+            self.set_tip_height()
+        return self.tip_height
+
+    def set_bg_color(self, color=(20, 10, 200, 100)):
+        self.bg_color = color
+
+    def get_bg_color(self):
+        if not self.bg_color:
+            self.set_bg_color()
+        return self.bg_color
+
+    def blit(self):
+        self.draw_bg()
+        self.pm.surface.blit(self.surface, self.dest)
 
     def set_circle_color(self, color):
         self.circle_color = color
@@ -439,8 +495,30 @@ class WordSurface():
         return self.get_y() + self.get_h() >= \
             self.pm.w_height - self.pm.wall_surface.h
 
+    def get_tip_dest(self):
+        return (
+            self.get_x() + self.get_w() / 2,
+            self.get_y() + self.get_h() + self.get_tip_height()
+        )
+
+    def get_bg_points(self):
+        return [
+            (self.get_x(), self.get_y()),
+            (self.get_x() + self.get_w(), self.get_y()),
+            (self.get_x() + self.get_w(), self.get_y() + self.get_h()),
+            self.get_tip_dest(),
+            (self.get_x(), self.get_y() + self.get_h())
+        ]
+
+    def draw_bg(self):
+        pygame.draw.polygon(
+            self.win.surface,
+            self.get_bg_color(),
+            self.get_bg_points())
+
     def get_surface(self):
-        return self.font.render(self.word, False, self.font_color)
+        _render = self.font.render(self.word, False, self.font_color)
+        return _render
 
     def set_dest(self, dest):
         self.dest = dest
@@ -457,10 +535,14 @@ class WordSurface():
     def get_h(self):
         return self.size[1]
 
-    def add_dest(self, _add):
-        self.dest[0] += _add[0]
-        self.dest[1] += _add[1]
+    def add_dest(self, _add, blit=False):
+        if self.dest[0] < self.win.w_width:
+            self.dest[0] += _add[0]
+        if self.dest[1] < self.win.w_height:
+            self.dest[1] += _add[1]
         self.center = self.get_center()
+        if blit:
+            self.blit()
 
     def set_laser_color(self, laser_color):
         self.laser_color = laser_color
@@ -484,7 +566,7 @@ class WordSurface():
         ]
 
     def get_circle_radius(self):
-        return self.get_w() / 2
+        return self.get_w() / 1.5
 
     def circle(self):
         pygame.draw.circle(
@@ -520,9 +602,7 @@ class WordSurface():
 
 class PinyinMissile(GameBase):
     def __init__(self, win):
-
         self.win = win
-
         # window
         self.w_width = self.win.w_width
         self.w_height = self.win.w_height
@@ -533,47 +613,36 @@ class PinyinMissile(GameBase):
         self.FPS = self.win.FPS
         self.clock = self.win.clock
         self._load = False
-
         self.subject = self.win.subject
         self.subject_index = self.win.subject_index
         self.subject_game_index = self.win.subject_game_index
         self.difficulty_index = self.win.difficulty_index
-
         self.main_menu = self.win.main_menu
         self.play_menu = self.win.play_menu
         self.save_menu = self.win.save_menu
         self.surface = self.win.surface
-
         self._input = ''
         self.font = get_default_font(45)
         self.info_surface = InfoSurface(self)
         self.wall_surface = WallSurface(self)
         self.input_surface = InputSurface(self)
-
         # word surface
         self.word = Word(self)
         self.words = self.word.get_words(self.difficulty_index)
         self.wordsurfaces_manager = WordSurfacesManager(self)
-
         self.wave = Wave(self)
-
         self.win_count = 0
         self.lose_count = 0
         self.word_count = len(self.words)
-
         self.copy_path = get_copy_path(module_str)
-
         self.print_game_info()
-
         self.last_timedelta = timedelta(0)
         self.start_time = datetime.now()
         self.end_time = None
-
         self._bg_img = None
 
-    def set_bg_img(self, src_name=None):
-        self._bg_img = pygame.image.load(
-            get_resource_path(src_name if src_name else '0x4.png'))
+    def set_bg_img(self, src_name='0x4.png'):
+        self._bg_img = pygame.image.load(get_resource_path(src_name))
         self._bg_img = pygame.transform.scale(
             self._bg_img, (self.w_width, self.w_height))
 
